@@ -1,7 +1,7 @@
 from django.urls import path
 from . import views
 
-app_name = 'django_authentication'
+app_name = 'django_single_auth'
 
 urlpatterns = [
     path('login/', views.ServerLogin.as_view(), name='login'),
